skalibs: the genalloc library interface
Keywords: skalibs c unix genalloc library libstddjb

libstddjb
libskarnet
skalibs
Software
skarnet.org

# The `genalloc` library interface

The following functions are declared in the `skalibs/genalloc.h` header, and implemented in the `libskarnet.a` or `libskarnet.so` library.

## General information

`genalloc` is the skalibs way of handling dynamic arrays, i.e. dynamically growing arrays of fixed-size objects. Any array that needs to be stored in heap memory can be implemented via genalloc.

Most genalloc functions are just macro calls around stralloc functions.

The `genalloc.h` header is actually very simple and the prototypes there are self-explaining.